=======
Credits
=======

Development Leads
-----------------

* Sigurd Naess (@amaurea)
* Mathew Madhavacheril (@msyriac)
* Matthew Hasselfield (@mhasself)

Contributors
------------

* Sigurd Naess (@amaurea)
* Mathew Madhavacheril (@msyriac)
* Matthew Hasselfield (@mhasself)
* Alex van Engelen
* Matt Hilton
